{% load static %}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link rel="stylesheet" href="{% static '/css/style.css' %}" />
    <title>Register</title>
  </head>
  <body>
    <div class="auth-container">
      <h1>Register</h1>
      <form method="post" enctype="multipart/form-data">
        {% csrf_token %}
            {{ form.email }}
            {% for error in form.email.errors %}
            <div class="error">{{ error }}</div>
            {% endfor %}
            {{ form.username }}
            {% for error in form.username.errors %}
            <div class="error">{{ error }}</div>
            {% endfor %}
            {{ form.password1 }}
            {% for error in form.password1.errors %}
            <div class="error">{{ error }}</div>
            {% endfor %}
            {{ form.password2 }}
            {% for error in form.password2.errors %}
            <div class="error">{{ error }}</div>
            {% endfor %}
        <button class="submit-button" type="submit">Submit</button>
      </form>
      <div class="links">
        <a href="{% url 'login' %}">Already have an account?</a>
      </div>
    </div>
  </body>
</html>
